@@ -46,6 +46,7 @@ ENDOFFILE = "End of file reached"
 STOPDATA = "Serial reader process stopped"
 NOTCONN = "Not connected"
 UBXPOLL = "Polling current UBX configuration..."
+MONSPANERROR = "Enable or poll MON-SPAN message"
 
 # Menu text
 MENUFILE = "File"
@@ -68,6 +69,8 @@ MENUHIDEMAP = "Hide Map"
 MENUSHOWMAP = "Show Map"
 MENUHIDESATS = "Hide Satellites"
 MENUSHOWSATS = "Show Satellites"
+MENUHIDESPECTRUM = "Hide Spectrum"
+MENUSHOWSPECTRUM = "Show Spectrum"
 MENUUBXCONFIG = "UBX Configuration Dialog"
 MENUNTRIPCONFIG = "NTRIP Configuration Dialog"
 MENUHOWTO = "How To"
@@ -111,6 +114,7 @@ LBLSERVERMODE = "Mode"
 LBLCFGDYN = "CFG-* Other Configuration"
 LBLGGALIVE = "Receiver"
 LBLGGAFIXED = "Fixed Reference"
+LBLUDPORT = "USER-DEFINED PORT"
 
 # Dialog text
 DLGUBXCONFIG = "UBX Configuration"
